summaryrefslogtreecommitdiff
path: root/unotools/source/config/cmdoptions.cxx
diff options
context:
space:
mode:
authorFridrich Strba <fridrich.strba@bluewin.ch>2011-02-03 16:55:17 -0700
committerFridrich Štrba <fridrich.strba@bluewin.ch>2011-02-04 01:10:15 +0100
commite99fcbe58ef7533da06ee4658a4ee2cde4df58ea (patch)
tree2dffe52eb92af74244d25f19613b1af187d9eab7 /unotools/source/config/cmdoptions.cxx
parentfad7c8f3e0d0518b1a6411d53d5d0a3a43adf119 (diff)
Bulk move libs-gui to boost unordered containers
Diffstat (limited to 'unotools/source/config/cmdoptions.cxx')
-rw-r--r--unotools/source/config/cmdoptions.cxx8
1 files changed, 4 insertions, 4 deletions
diff --git a/unotools/source/config/cmdoptions.cxx b/unotools/source/config/cmdoptions.cxx
index 3d8fea23c175..84a48390780d 100644
--- a/unotools/source/config/cmdoptions.cxx
+++ b/unotools/source/config/cmdoptions.cxx
@@ -46,7 +46,7 @@
#include <itemholder1.hxx>
#include <algorithm>
-#include <hash_map>
+#include <boost/unordered_map.hpp>
//_________________________________________________________________________________________________________________
// namespaces
@@ -143,7 +143,7 @@ class SvtCmdOptions
}
private:
- class CommandHashMap : public ::std::hash_map< ::rtl::OUString ,
+ class CommandHashMap : public ::boost::unordered_map< ::rtl::OUString ,
sal_Int32 ,
OUStringHashCode ,
::std::equal_to< ::rtl::OUString > >
@@ -292,7 +292,7 @@ SvtCommandOptions_Impl::SvtCommandOptions_Impl()
sal_Int32 nItem = 0 ;
OUString sCmd ;
// Set size of hash_map reach a used size of approx. 60%
m_aDisabledCommands.SetContainerSize( lNames.getLength() * 10 / 6 );
// Get names/values for disabled commands.
@@ -343,7 +343,7 @@ void SvtCommandOptions_Impl::Notify( const Sequence< OUString >& )
sal_Int32 nItem = 0 ;
OUString sCmd ;
// Set size of hash_map reach a used size of approx. 60%
m_aDisabledCommands.Clear();
m_aDisabledCommands.SetContainerSize( lNames.getLength() * 10 / 6 );
@@ -292,7 +292,7 @@ SvtCommandOptions_Impl::SvtCommandOptions_Impl()
sal_Int32 nItem = 0 ;
OUString sCmd ;
- // Set size of hash_map reach a used size of approx. 60%
+ // Set size of boost::unordered_map reach a used size of approx. 60%
m_aDisabledCommands.SetContainerSize( lNames.getLength() * 10 / 6 );
// Get names/values for disabled commands.
@@ -343,7 +343,7 @@ void SvtCommandOptions_Impl::Notify( const Sequence< OUString >& )
sal_Int32 nItem = 0 ;
OUString sCmd ;
- // Set size of hash_map reach a used size of approx. 60%
+ // Set size of boost::unordered_map reach a used size of approx. 60%
m_aDisabledCommands.Clear();
m_aDisabledCommands.SetContainerSize( lNames.getLength() * 10 / 6 );